@@ -468,35 +468,73 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
-        :param VoiceFileType: 语音文件类型 	1: raw, 2: wav, 3: mp3, 4: speex (语言文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败)。
+        :param VoiceFileType: 语音文件类型
+1: raw
+2: wav
+3: mp3
+4: speex
+语音文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败。
         :type VoiceFileType: int
-        :param VoiceEncodeType: 语音编码类型	1:pcm。
+        :param VoiceEncodeType: 语音编码类型
+1:pcm
         :type VoiceEncodeType: int
-        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为0.5k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
+        :param UserVoiceData: 当前数据包数据, 流式模式下数据包大小可以按需设置，在网络良好的情况下，建议设置为1k，且必须保证分片帧完整（16bit的数据必须保证音频长度为偶数），编码格式要求为BASE64。
         :type UserVoiceData: str
-        :param SessionId: 语音段唯一标识，一个完整语音一个SessionId。
+        :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
-        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
+        :param RefText: 被评估语音对应的文本，仅支持中文和英文。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
-        :param WorkMode: 语音输入模式，0：流式分片，1：非流式一次性评估
+        :param WorkMode: 语音输入模式
+0：流式分片
+1：非流式一次性评估
+推荐使用流式分片传输。
         :type WorkMode: int
-        :param EvalMode: 评估模式，0：词模式（中文评测模式下为文字模式），1：句子模式，2：段落模式，3：自由说模式，当为词模式评估时，能够提供每个音节的评估信息，当为句子模式时，能够提供完整度和流利度信息，4：单词纠错模式：能够对单词和句子中的读错读音进行纠正，给出参考正确读音。
+        :param EvalMode: 评测模式
+0：单词/单字模式（中文评测模式下为单字模式）
+1：句子模式
+2：段落模式
+3：自由说模式
+4：单词音素纠错模式
+5：情景评测模式
+6：句子多分支评测模式
+7：单词实时评测模式
+8：拼音评测模式
         :type EvalMode: int
-        :param ScoreCoeff: 评价苛刻指数，取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数，1.0为小年龄段，4.0为最高年龄段
+        :param ScoreCoeff: 评价苛刻指数。取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数。
+1.0：适用于最小年龄段用户，一般对应儿童应用场景；
+4.0：适用于最高年龄段用户，一般对应成人严格打分场景。
         :type ScoreCoeff: float
-        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。
+        :param SoeAppId: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 SoeAppId 可以在[控制台](https://console.cloud.tencent.com/soe)【应用管理】下新建。如果没有新建SoeAppId，请勿填入该参数，否则会报欠费错误。
         :type SoeAppId: str
-        :param StorageMode: 音频存储模式，0：不存储，1：存储到公共对象存储，输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段，2：永久存储音频，需要提工单申请，会产生一定存储费用，3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中，需要提工单登记存储信息。
+        :param StorageMode: 音频存储模式
+0：不存储
+1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
+2：永久存储音频，需要提工单申请，会产生一定的存储费用；
+3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中，需要提工单登记存储信息。关于自定义存储cos基础设置的方式，请查看下文自定义存储cos基础设置流程。
+注：对可用性要求较高的用户建议自行存储至腾讯云COS。
         :type StorageMode: int
-        :param SentenceInfoEnabled: 输出断句中间结果标识，0：不输出，1：输出，通过设置该参数，可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
+        :param SentenceInfoEnabled: 输出断句中间结果标识
+0：不输出
+1：输出，通过设置该参数
+可以在评估过程中的分片传输请求中，返回已经评估断句的中间结果，中间结果可用于客户端 UI 更新，输出结果为TransmitOralProcess请求返回结果 SentenceInfoSet 字段。
         :type SentenceInfoEnabled: int
-        :param ServerType: 评估语言，0：英文，1：中文。
+        :param ServerType: 评估语言
+0：英文
+1：中文
         :type ServerType: int
-        :param IsAsync: 异步模式标识，0：同步模式，1：异步模式，可选值参考[服务模式](https://cloud.tencent.com/document/product/884/33697)。
+        :param IsAsync: 异步模式标识
+0：同步模式
+1：异步模式（一般情况不建议使用异步模式）
+可选值参考[服务模式](https://cloud.tencent.com/document/product/884/33697)。
         :type IsAsync: int
         :param IsQuery: 查询标识，当该参数为1时，该请求为查询请求，请求返回该 Session 评估结果。
         :type IsQuery: int
-        :param TextMode: 输入文本模式，0: 普通文本，1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本。2：音素注册模式（提工单注册需要使用音素的单词）。
+        :param TextMode: 输入文本模式
+0: 普通文本
+1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本
+2：音素注册模式（提工单注册需要使用音素的单词）。
         :type TextMode: int
         """
         self.SeqId = None
